@@ -19,6 +19,7 @@ import logging
 from mrack.errors import ApplicationError
 from mrack.host import STATUS_ACTIVE
 from mrack.providers.utils.podman import Podman
+from mrack.utils import global_context
 from mrack.utils import ssh_to_host as utils_ssh_to_host
 
 logger = logging.getLogger(__name__)
@@ -36,6 +37,9 @@ class SSH:
         self._metadata = metadata
         self._db = db_driver
 
+        global_context["metadata"] = metadata
+        global_context["config"] = config
+
     def pick_host_interactively(self, hosts):
         """Print list of host and let user to choose one."""
         # With only 1 host available, we can pick it and save time
@@ -93,7 +97,7 @@ class SSH:
         """Simulate SSH by attaching an interactive session to a container."""
         if host.provider.name == "podman":
             podman = Podman()
-            podman.interactive(host.id)
+            podman.interactive(host.host_id)
         else:
             raise NotImplementedError("Docker is not yet supported.")
 
